<template>
  <div v-if="isShowBreadcrumb" class="layout-navbars-breadcrumb">
    <SvgIcon class="layout-navbars-breadcrumb-icon" :name="themeConfig.isCollapse ? 'ele-Expand' : 'ele-Fold'" :size="16"
      @click="onThemeConfigChange" />
    <el-breadcrumb class="layout-navbars-breadcrumb-hide">
      <transition-group name="breadcrumb">
        <el-breadcrumb class="layout-navbars-breadcrumb-hide">
          <transition-group name="breadcrumb">
            <!-- {{breadcrumbList}} -->
            <el-breadcrumb-item v-for="(v, k) in breadcrumbList"
              :key="!v.meta.tagsViewName ? v.meta.title : v.meta.tagsViewName">
              <span v-if="k === breadcrumbList.length - 1" class="layout-navbars-breadcrumb-span">
                <SvgIcon :name="v.meta.icon" class="layout-navbars-breadcrumb-iconfont"
                  v-if="themeConfig.isBreadcrumbIcon" />
                <div v-if="!v.meta.tagsViewName">{{ $t(v.meta.title) }}</div>
                <div v-else>{{ v.meta.tagsViewName }}</div>
              </span>
              <a v-else @click.prevent="onBreadcrumbClick(v)">
                <SvgIcon :name="v.meta.icon" class="layout-navbars-breadcrumb-iconfont"
                  v-if="themeConfig.isBreadcrumbIcon" />
                {{ $t(v.meta.title) }}
              </a>
            </el-breadcrumb-item>
          </transition-group>
        </el-breadcrumb>
      </transition-group>
    </el-breadcrumb>
  </div>
</template>

<script setup lang="ts">
import { ref, reactive, toRef, toRefs, onMounted, getCurrentInstance, toRaw, computed } from 'vue'
import { useThemeConfig } from '/@/stores/themeConfig'
import { storeToRefs } from 'pinia';
import { onBeforeRouteUpdate, useRoute, useRouter } from 'vue-router';
import { useRoutesList } from '/@/stores/routesList'
import other from '/@/utils/other';
import { Local } from '/@/utils/storage';
interface BreadcrumbState {
  breadcrumbList: Array<any>;
  routeSplit: Array<string>;
  routeSplitFirst: string;
  routeSplitIndex: number;
}

const storesThemeConfig = useThemeConfig()
const { themeConfig } = storeToRefs(storesThemeConfig)

const route = useRoute()
const router = useRouter()
const state = reactive<BreadcrumbState>({
  breadcrumbList: [],
  routeSplit: [],
  routeSplitFirst: '',
  routeSplitIndex: 1
})
const { breadcrumbList } = toRefs(state)

const stores = useRoutesList()
const { routesList } = storeToRefs(stores)

// 动态设置经典、横向布局不显示
const isShowBreadcrumb = computed(() => {
  initRouteSplit(route.path)//初始化路由分割--核心代码55
  const { layout, isBreadcrumb } = themeConfig.value
  console.log(isBreadcrumb)//true
  if (layout === 'classic' || layout === 'transverse') return false;
  else return isBreadcrumb ? true : false;
})



// 当前路由字符串切割成数组，并删除第一项空内容
const initRouteSplit = (path: string) => {
  console.log(path)
  console.log(routesList)
  if (!themeConfig.value.isBreadcrumb) return false;
  state.breadcrumbList = [routesList.value[0]]//第一个数据，返回home路由对象
  console.log(state.breadcrumbList)
  //  debugger
  state.routeSplit = path.split('/')
  state.routeSplit.shift()//http://**:2000/#/system/menu 当前路由路径数组['system', 'menu']
  state.routeSplitFirst = `/${state.routeSplit[0]}`//返回 '/system'
  state.routeSplitIndex = 1
  console.log(state.routeSplit)
  console.log(state.routeSplitFirst)//  '/system'
  let aa = toRaw(state.routeSplit)
  console.log(aa)//当前路由路径数组['system', 'menu']
  getBreadcrumbList(routesList.value)
  console.log(toRaw(state.breadcrumbList))
  if (route.name === 'home' || (route.name === 'notFound' && state.breadcrumbList.length > 1)) state.breadcrumbList.shift() //删除第一项空内容
  if (state.breadcrumbList.length > 0) state.breadcrumbList[state.breadcrumbList.length - 1].meta.tagsViewName = other.setTagsViewNameI18n(route)//返回meta.title国际化标题, '首页'
  console.log(toRaw(state.breadcrumbList))
}
// 处理面包屑数据--返回面包屑的item路由对象组成数组[]
const getBreadcrumbList = (arr: Array<string>) => {
  console.log(arr)
  arr && arr.length && arr.forEach((item: any) => {
    state.routeSplit && state.routeSplit.length && state.routeSplit.forEach((v: any, k: number, arrs: any) => {
      console.log(arrs)
      if (state.routeSplitFirst === item.path) {
        state.routeSplitFirst += `/${arrs[state.routeSplitIndex]}`//arrs[1]=menu===> '/system/menu'
        console.log(state.breadcrumbList)
        state.breadcrumbList.push(item)
        state.routeSplitIndex++;
        if (item.children) getBreadcrumbList(item.children)
      }
    })
  })
}
// 面包屑点击时
const onBreadcrumbClick = (v: any) => {
  const { redirect, path } = v
  if (redirect) router.push(redirect)
  else router.push(path)
}
// 展开/收起左侧菜单点击
const onThemeConfigChange = () => {
  console.log('三个横符号点击切换展开与收起')
  themeConfig.value.isCollapse = !themeConfig.value.isCollapse
  setLocalThemeConfig()//自动修改本地localStorage布局的设置
}
// 存储布局配置--自动修改本地localStorage布局的设置
const setLocalThemeConfig = () => {
  Local.remove('themeConfig')
  Local.set('themeConfig', themeConfig.value)
}
// 页面加载时
onMounted(() => {
  initRouteSplit(route.path)
})
// 路由更新时
onBeforeRouteUpdate((to) => {
  initRouteSplit(to.path)
})
</script>
<style scoped lang="scss">
.layout-navbars-breadcrumb {
  flex: 1;
  height: inherit;
  display: flex;
  align-items: center;

  .layout-navbars-breadcrumb-icon {
    cursor: pointer;
    font-size: 18px;
    color: var(--next-bg-topBarColor);
    height: 100%;
    width: 40px;
    opacity: 0.8;

    &:hover {
      opacity: 1;
    }
  }

  .layout-navbars-breadcrumb-span {
    display: flex;
    opacity: 0.7;
    color: var(--next-bg-topBarColor);
  }

  .layout-navbars-breadcrumb-iconfont {
    font-size: 14px;
    margin-right: 5px;
  }

  :deep(.el-breadcrumb__separator) {
    opacity: 0.7;
    color: var(--next-bg-topBarColor);
  }

  :deep(.el-breadcrumb__inner a, .el-breadcrumb__inner.is-link) {
    font-weight: unset !important;
    color: var(--next-bg-topBarColor);

    &:hover {
      color: var(--el-color-primary) !important;
    }
  }
}
</style>
